<template>
  <div>
    <div v-show="step1">
      <h1>Step 1: Choose your stories</h1>
      <p>Please select from the following options:</p>
      <section id="stories-options">
        <template v-for="layout in shop.layouts">
          <section
            @click="newspaperLayoutControls(layout.id, shop.layouts); ready = true; ready1 = true;"
            :id="`storyOption${layout.id}`"
            :key="layout.id"
            class="choose"
            :class="{ 'selected': layout.selected}" >
            <div class="select">
              <div class="inner">
                <div class="dot"></div>
              </div>
            </div>
            <div class="stories">
              <div class="inner">
                <p
                  v-for="(title, index) in layout.article_titles"
                  :key="index">{{ title.article_title }}
                </p>
              </div>
            </div>
          </section>
        </template>
        <div class="clearfix"></div>
        <div class="next-step">
          <a
            @click="step2 = true; step1 = false; ready = false"
            class="button"
            :class="{'ready': ready, 'ready': ready1}">CONTINUE TO STEP 2</a>
        </div>
      </section>
    </div>
    <div
      v-show="step2">
      <h1>Step 2: Choose a Wellness Tip</h1>
      <p>Please select from the following options:</p>
      <div id="wellness-tips">
        <div class="list">
          <template v-for="tip in shop.wellness_tips">
            <section
              @click="newspaperLayoutControls(tip.id, shop.wellness_tips); ready = true; ready2 = true;"
              :key="tip.id"
              :class="{selected: tip.selected}"
              class="choose">
              <div class="select">
                <div class="inner">
                  <div class="dot"></div>
                </div>
              </div>
              <div class="tip">
                <div class="inner">
                  <p>{{ tip.tip }}</p>
                </div>
              </div>
            </section>
          </template>
        </div>
        <div class="clearfix"></div>
        <div class="next-step">
          <a
            @click="step3 = true; step2 = false; ready = false;"
            class="button"
            :class="{'ready': ready, 'ready': ready2}">CONTINUE TO STEP 3</a>
          <!-- <a
            @click="step3 = true; step2 = false; ready = false; getShops();"
            class="button"
            :class="{'ready': ready, 'ready': ready2}">CONTINUE TO STEP 3</a> -->
        </div>
      </div>
    </div>
    <div v-show="step3">
      <h1>Step 3: Choose a Word Puzzle</h1>
      <p>Please select from the following options:</p>
      <section id="word-puzzles">
        <template v-for="(puzzle,index) in shop.word_puzzles">
          <section
            @click="newspaperLayoutControls(puzzle.id, shop.word_puzzles); ready = true; ready3 = true;"
            :id="`wordPuzzle${puzzle.id}`"
            :key="puzzle.id"
            class="choose"
            :class="{'left': index % 2 == 0,'right': index % 2 == 1, 'selected': puzzle.selected}">
            <div class="select">
              <div class="inner">
                <div class="dot"></div>
              </div>
            </div>
            <div class="puzzle">
              <div class="inner">
                <img
                  :src="puzzle.path"
                  :value="puzzle.answer"
                  alt="word puzzle image">
              </div>
            </div>
          </section>
        </template>
        <div class="clearfix"></div>
        <div class="next-step">
          <!-- TODO: will need to chage this @click when ads are back on the table -->
          <a
            @click="step3 = false; step1 = true;"
            :class="{'ready': ready, 'ready': ready3}"
            class="button">GO BACK TO STORY OPTIONS</a>
          <p v-show="ready3"><br>OR</p>
          <a
            @click="completeLayout(); step3 = false; step1 = true;"
            :class="{'ready': ready, 'ready': ready3}"
            class="button">COMPLETE LAYOUT!</a>
        </div>
      </section>
    </div>
    <!-- <div v-show="step4">
      <h1 id="ads-tab-header">Step 4: Choose Advertisement Images</h1>
      <p>Please choose the images you would like to use for each of the shop advertisements.</p>
      <div id="choose-ads">
        <ul class="errors"></ul>
        <template v-for="(shop,index) in shops">
          <section
            :key="index"
            id="choose-ad"
            class="choose">
            <div class="shop-name">{{ shop.name }}</div>
            <div class="ad-image">
              <img src="" alt="">
            </div>
            <div class="clearfix"></div>
            <a href="" id="button-ad" class="button choose-image">CHOOSE IMAGE</a>

          </section>
        </template>
        <div class="clearfix"></div>
        <div class="next-step">
          <a
            @click="step4 = false; step1 = true;"
            class="button submit">GO BACK TO STORY OPTIONS</a>
        </div>
      </div>
    </div> -->
  </div>
</template>

<script>
export default {
  props: {
    shop: Object,
  },
  data() {
    return {
      step1: true,
      step2: false,
      step3: false,
      step4: false,
      ready: false,
      ready1: false,
      ready2: false,
      ready3: false,
      shops: []
    }
  },
  methods: {
    newspaperLayoutControls(element, array) {
      let self = this;
      //changes UI for a selected option
      array.forEach(function (object) {
        if(object.id == element) {
          object.selected = true;
        } else {
          object.selected = false;
        }
      });
      //saves selected object to state in prep to post
      array.forEach(function (object) {
        if(object.selected && self.step1) {
          self.shop.selected_layout_id = object.id;
        } else if (object.selected && self.step2) {
          self.shop.selected_wellness_tip_id = object.id;
        } else if (object.selected && self.step3) {
          self.shop.selected_word_puzzle_id = object.id;
        }
      });
      this.putNewsPaperLayout();
    },
    // getShops() {
      // don't need until we upload images for ads
      // app.api.Get( `shops/getAllWithPrettyNames/`)
      //   .then( Response => {
      //     this.shops = Response;
      //   })
      //   .catch( x => app.Message( x.error, "error" ) )
    // },
    completeLayout() {
      this.$router.push({name: 'newspapereditstory'});
    },
    putNewsPaperLayout() {
      // put this on the shop model.
      // conditional to use either prop or data()
      app.session.SetSession()
        .then( () => {
          app.api.Put("newspaper/editshop/" + this.shop.id, this.shop)
          .then(Response => {
            this.$emit('saved-paper');
          })
          .catch( x => app.Message(x.error, "error"));
        })
    }
  }
}
</script>

<style>

</style>
